#!/bin/bash

DEBUG=echo
#DEBUG=:


#Source functions, may need to set path
source createicons.sh
source mountcifs.sh
source mountncp.sh
source mountsshfs.sh

CONFIGFILE="./login.cfg"
source ${CONFIGFILE}


#define functions

#Test if mount point exists, need to add code to check if success or fail and if mount is readable
#or will overwrite existing data. Dir created with "mkdir -m 700 test" for drwx------
test_dir_exists()
{
${DEBUG} ""
${DEBUG} "=>Checking if mount point exists"
if [ -d ${1} ]; then
        ${DEBUG} "==>Mount point ${1} exists"
	test_dir_empty ${1}
else
	${DEBUG} "==>Creating mount point ${1}"
        mkdir -m 700 ${1}
fi
}

#Test if mount point is empty, or will mounting overmount files, ${1} is dir to test.
test_dir_empty()
{
${DEBUG} ""
${DEBUG} "=>Checking if mount point is empty"
echo ${1}/* | grep '\*$' > 2&>1
DIRRC=$?
if [ ${DIRRC} -eq 0 ]; then
        ${DEBUG} "==>Mount point directory ${1} is empty"
else
        ${DEBUG} "==>Mount point directory ${1} is NOT empty, Mounting will hide some files."
fi
}

#Test if mount point is already mounted
test_mountpoint()
{
${DEBUG} ""
${DEBUG} "=>Checking to see if ${1} is mounted."
mount | grep ${1}  
#2&>1
MPBUSYRC=$?
if [ ${MPBUSYRC} -eq 0 ]; then 
	${DEBUG} "==>Mount point ${1} is already mounted."
	MOUNTSTATUS=0
	exit 99
else
	${DEBUG} "==>Mount point ${1} is available."	
fi
}



#Function to get users passwords
#$ cat  login.cfg | grep LOGIN_FSTYPE
#LOGIN_FSTYPE[0]=cifs               
#LOGIN_FSTYPE[1]=sshfs              
#LOGIN_FSTYPE[2]=cifs

getpassword()
{
${DEBUG} "Passwords are not used from here yet! You can ignore this prompt."

if [ `cat ${CONFIGFILE} | grep 'LOGIN_FSTYPE' | grep cifs` ];then
	echo -n "CIFS password:- "
	read -s CIFSPASSWORD
	echo " "
	if [ -n "${CIFSPASSWORD}" ];then
		echo "CIFS pw is valid"
		else
		echo "CIFS pw is blank"
	fi


elif [ `cat ${CONFIGFILE} | grep LOGIN_FSTYPE | grep sshfs` ];then
	echo -n "SSHFS password:- "
	read -s SSHFSPASSWORD
	echo " "
	if [ -n "${SSHFSPASSWORD}" ];then
		echo "SSHFS pw is valid"
		else
		echo "SSHFS pw is blank"
	fi	


elif [ `cat ${CONFIGFILE} | grep LOGIN_FSTYPE | grep ncp` ];then
	echo -n "NCP password:- "
	read -s NCPPASSWORD
	echo " "
	if [ -n "${NCPPASSWORD}" ];then
		echo "NCP pw is valid"
		else
		echo "NCP pw is blank"
	fi
fi

#echo "CIFS Password is >${CIFSPASSWORD}<"
#echo "SSHFS Password is >${SSHFSPASSWORD}<"
#echo "NCP Password is >${NCPPASSWORD}<"
}


#==========================End of functions================================




#++++++++++++++++++++++++++Main Code+++++++++++++++++++++++++++++++++++++++

${DEBUG} "==> Debug mode is ON <=="

${DEBUG} "=> You're using ${DESKTOP_SESSION} <="

#Set up command names, paths are found in osguess block
SSHFS=sshfs
CIFS=mount.cifs
NCPLOGIN=ncplogin
NCPMAP=ncpmap
NCPMOUNT=mount.ncpfs

#Try to guess the OS to set location for binaries which may not be in the $PATH
OSGUESS=`uname -a | cut -d" " -f1 -`

if [ "${OSGUESS}" == "Linux" ];then
        ${DEBUG} "OS is Linux"

	SSHFSPATH=/usr/bin
	${DEBUG} "sshfs is ${SSHFSPATH}/${SSHFS}"

	CIFSPATH=/sbin
	${DEBUG} "cifs is ${CIFSPATH}/${CIFS}"
	
	NCPPATH=/sbin
	${DEBUG} "ncpfs is ${NCPPATH}/${NCPMOUNT}"


elif [ "${OSGUESS}" == "Darwin" ];then
        ${DEBUG} "OS is Mac - OsX"

	SSHFSPATH=/Applications/sshfs/bin
	SSHFS=mount_sshfs
	${DEBUG} "sshfs is ${SSHFSPATH}/${SSHFS}"
	CIFSPATH=/sbin

	CIFS=mount_smbfs
	${DEBUG} "cifs is ${CIFSPATH}/${CIFS}"
	NCPPATH=/usr/bin

else
        ${DEBUG} "OS unsupported, but this is OpenSource, so try to fix it!"
        exit 1
fi

#Get users passwords for future use.
getpassword


# Loop though the arrays and mount each using the login_* functions.
for (( I=0; $I < ${#LOGIN_SERVER[*]}; I++ )); do
  login_${LOGIN_FSTYPE[$I]} $I
  if [ $? -ne 0 ]; then
    echo "Mount error, wrong fs type maybe?"
    exit 1
  fi
done

echo ""
#show cifs mounts
echo "********* Current CIFS Connections *********"
mount |grep cifs
echo "********************************************"
echo""
echo "********* Current SSH_FS Connections *********"
mount |grep sshfs
echo "********************************************"
echo""


exit 0

